injection

package
v0.0.0-...-312bc49 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 30, 2021 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

const (
	// MEM_COMMIT is a Windows constant used with Windows API calls
	MEM_COMMIT = 0x1000
	// MEM_RESERVE is a Windows constant used with Windows API calls
	MEM_RESERVE = 0x2000
	// PAGE_EXECUTE_READ is a Windows constant used with Windows API calls
	PAGE_EXECUTE_READ = 0x20
	// PAGE_READWRITE is a Windows constant used with Windows API calls
	PAGE_READWRITE = 0x04
)
const (
	QUEUE_USER_APC_FLAGS_NONE = iota
	QUEUE_USER_APC_FLAGS_SPECIAL_USER_APC
	QUEUE_USER_APC_FLGAS_MAX_VALUE
)

Variables

var CloseHandle *windows.LazyProc
var ConvertThreadToFiber *windows.LazyProc
var CreateFiber *windows.LazyProc
var CreateRemoteThread *windows.LazyProc
var CreateThread *windows.LazyProc
var EnumSystemLocalesA *windows.LazyProc
var EtwpCreateEtwThread *windows.LazyProc
var GetCurrentThread *windows.LazyProc
var HeapAlloc *windows.LazyProc
var HeapCreate *windows.LazyProc
var NtQueryInformationProcess *windows.LazyProc
var NtQueueApcThreadEx *windows.LazyProc
var QueueUserAPC *windows.LazyProc
var ReadProcessMemory *windows.LazyProc
var RtlCopyMemory *windows.LazyProc
var RtlCreateUserThread *windows.LazyProc
var SwitchToFiber *windows.LazyProc
var UuidFromString *windows.LazyProc
var VirtualAlloc *windows.LazyProc
var VirtualAllocEx *windows.LazyProc
var VirtualProtect *windows.LazyProc
var VirtualProtectEx *windows.LazyProc
var WaitForSingleObject *windows.LazyProc
var WriteProcessMemory *windows.LazyProc

Functions

func CreateEtwThread

func CreateEtwThread()

func CreateProcess

func CreateProcess()

func CreateProcessWithPipe

func CreateProcessWithPipe()

func CreateThreads

func CreateThreads()

func EarlyBird

func EarlyBird()

func NtQueueApcThread

func NtQueueApcThread()

func RtlCreateUserThreads

func RtlCreateUserThreads()

func Syscall

func Syscall()

func UUIDFromString

func UUIDFromString()

Types

This section is empty.

Jump to